households : Households — amici1

# `households` : Households

See also `lino_amici.lib.households`.

## Models

## Actors

- Household Member Dependencies : (no docstring)

- Household member roles : (no docstring)

- Household Types : (no docstring)

- Households : (no docstring)

- Households : (no docstring)

- Household Members : (no docstring)

- Household Members : (no docstring)

- Household composition : (no docstring)

- Household memberships : (no docstring)